/*
 * Copyright 2019-2023 PixlOne
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LOGID_BACKEND_ERROR_H
#define LOGID_BACKEND_ERROR_H

#include <stdexcept>

namespace logid::backend {
    class DeviceNotReady : public std::exception {
    public:
        [[nodiscard]] const char* what() const noexcept override;
    };

    class TimeoutError : public std::exception {
    public:
        TimeoutError() = default;

        [[nodiscard]] const char* what() const noexcept override;
    };
}

#endif //LOGID_BACKEND_ERROR_H